slice

package
v0.0.0-...-68678b1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2021 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Int64IndexOf

func Int64IndexOf(slice []int64, value int64) int

Int64IndexOf returns the index of a given integer in a slice, or -1 if not found

func StringIndexOf

func StringIndexOf(slice []string, value string) int

StringIndexOf returns the index of a given string in a slice, or -1 if not found

Types

This section is empty.

Jump to