Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Int64IndexOf ¶
Int64IndexOf returns the index of a given integer in a slice, or -1 if not found
func StringIndexOf ¶
StringIndexOf returns the index of a given string in a slice, or -1 if not found
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.